@@ -22,6 +22,7 @@
 require 5.004;
 use strict;
 
+require HTML::EP;
 require HTML::EP::Config;
 
 
@@ -48,7 +49,7 @@ sub init ($) {
 	    if ($self->{env}->{PATH_TRANSLATED} =~ /\.(\w+)\.\w+$/) {
 		$lang = $1;
 	    } else {
-		$lang = $HTML::EP::Config::CONFIGURATION->{'default_langauge'};
+		$lang = $HTML::EP::Config::CONFIGURATION->{'default_language'};
 	    }
 	}
 	$self->{_ep_language} = $lang;
